@@ -23,8 +23,6 @@ jest.mock("electron", () => ({
 
 import type { UserStore } from "../user-store";
 import { Console } from "console";
-import { SemVer } from "semver";
-import electron from "electron";
 import { stdout, stderr } from "process";
 import userStoreInjectable from "../user-store/user-store.injectable";
 import type { DiContainer } from "@ogre-tools/injectable";
@@ -34,7 +32,9 @@ import { defaultThemeId } from "../vars";
 import writeFileInjectable from "../fs/write-file.injectable";
 import { getDiForUnitTesting } from "../../main/getDiForUnitTesting";
 import getConfigurationFileModelInjectable from "../get-configuration-file-model/get-configuration-file-model.injectable";
-import appVersionInjectable from "../vars/app-version.injectable";
+import storeMigrationVersionInjectable from "../vars/store-migration-version.injectable";
+import releaseChannelInjectable from "../vars/release-channel.injectable";
+import defaultUpdateChannelInjectable from "../application-update/selected-update-channel/default-update-channel.injectable";
 
 console = new Console(stdout, stderr);
 
@@ -42,7 +42,7 @@ describe("user store tests", () => {
   let userStore: UserStore;
   let di: DiContainer;
 
-  beforeEach(() => {
+  beforeEach(async () => {
     di = getDiForUnitTesting({ doGeneralOverrides: true });
 
     mockFs();
@@ -52,6 +52,12 @@ describe("user store tests", () => {
     di.permitSideEffects(getConfigurationFileModelInjectable);
     di.permitSideEffects(userStoreInjectable);
 
+    di.override(releaseChannelInjectable, () => ({
+      get: () => "latest" as const,
+      init: async () => {},
+    }));
+    await di.inject(defaultUpdateChannelInjectable).init();
+
     di.unoverride(userStoreInjectable);
   });
 
@@ -64,6 +70,7 @@ describe("user store tests", () => {
       mockFs({ "some-directory-for-user-data": { "config.json": "{}", "kube_config": "{}" }});
 
       userStore = di.inject(userStoreInjectable);
+      userStore.load();
     });
 
     it("allows setting and retrieving lastSeenAppVersion", () => {
@@ -86,13 +93,6 @@ describe("user store tests", () => {
       userStore.resetTheme();
       expect(userStore.colorTheme).toBe(defaultThemeId);
     });
-
-    it("correctly calculates if the last seen version is an old release", () => {
-      expect(userStore.isNewVersion).toBe(true);
-
-      userStore.lastSeenAppVersion = (new SemVer(electron.app.getVersion())).inc("major").format();
-      expect(userStore.isNewVersion).toBe(false);
-    });
   });
 
   describe("migrations", () => {
@@ -125,9 +125,10 @@ describe("user store tests", () => {
         },
       });
 
-      di.override(appVersionInjectable, () => "10.0.0");
+      di.override(storeMigrationVersionInjectable, () => "10.0.0");
 
       userStore = di.inject(userStoreInjectable);
+      userStore.load();
     });
 
     it("sets last seen app version to 0.0.0", () => {
