@@ -3,7 +3,7 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { CrdResources } from "./crd-resources";
+import { CustomResources } from "./crd-resources";
 import customResourcesRouteInjectable from "../../../common/front-end-routing/routes/cluster/custom-resources/custom-resources/custom-resources-route.injectable";
 import { routeSpecificComponentInjectionToken } from "../../routes/route-specific-component-injection-token";
 
@@ -12,7 +12,7 @@ const customResourcesRouteComponentInjectable = getInjectable({
 
   instantiate: (di) => ({
     route: di.inject(customResourcesRouteInjectable),
-    Component: CrdResources,
+    Component: CustomResources,
   }),
 
   injectionToken: routeSpecificComponentInjectionToken,
