@@ -3,8 +3,7 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import glob from "glob";
-import { memoize, noop, chunk } from "lodash/fp";
+import { noop, chunk } from "lodash/fp";
 import type { DiContainer, Injectable } from "@ogre-tools/injectable";
 import {
   createContainer,
@@ -19,9 +18,6 @@ import extensionsStoreInjectable from "../extensions/extensions-store/extensions
 import type { ExtensionsStore } from "../extensions/extensions-store/extensions-store";
 import fileSystemProvisionerStoreInjectable from "../extensions/extension-loader/file-system-provisioner-store/file-system-provisioner-store.injectable";
 import type { FileSystemProvisionerStore } from "../extensions/extension-loader/file-system-provisioner-store/file-system-provisioner-store";
-import clusterStoreInjectable from "../common/cluster-store/cluster-store.injectable";
-import type { ClusterStore } from "../common/cluster-store/cluster-store";
-import type { Cluster } from "../common/cluster/cluster";
 import userStoreInjectable from "../common/user-store/user-store.injectable";
 import type { UserStore } from "../common/user-store";
 import getAbsolutePathInjectable from "../common/path/get-absolute-path.injectable";
@@ -36,13 +32,9 @@ import { ApiManager } from "../common/k8s-api/api-manager";
 import lensResourcesDirInjectable from "../common/vars/lens-resources-dir.injectable";
 import broadcastMessageInjectable from "../common/ipc/broadcast-message.injectable";
 import apiManagerInjectable from "../common/k8s-api/api-manager/manager.injectable";
-import ipcRendererInjectable from "./utils/channel/ipc-renderer.injectable";
-import type { IpcRenderer } from "electron";
 import setupOnApiErrorListenersInjectable from "./api/setup-on-api-errors.injectable";
-import { observable, computed } from "mobx";
+import { observable, computed, runInAction } from "mobx";
 import defaultShellInjectable from "./components/+preferences/default-shell.injectable";
-import appVersionInjectable from "../common/vars/app-version.injectable";
-import provideInitialValuesForSyncBoxesInjectable from "./utils/sync-box/provide-initial-values-for-sync-boxes.injectable";
 import requestAnimationFrameInjectable from "./components/animate/request-animation-frame.injectable";
 import getRandomIdInjectable from "../common/utils/get-random-id.injectable";
 import getFilePathsInjectable from "./components/+preferences/kubernetes/helm-charts/adding-of-custom-helm-repository/helm-file-input/get-file-paths.injectable";
@@ -73,33 +65,37 @@ import forceUpdateModalRootFrameComponentInjectable from "./application-update/f
 import legacyOnChannelListenInjectable from "./ipc/legacy-channel-listen.injectable";
 import getEntitySettingCommandsInjectable from "./components/command-palette/registered-commands/get-entity-setting-commands.injectable";
 import storageSaveDelayInjectable from "./utils/create-storage/storage-save-delay.injectable";
+import type { GlobalOverride } from "../common/test-utils/get-global-override";
+import type { PartialDeep } from "type-fest";
 
-export const getDiForUnitTesting = (opts: { doGeneralOverrides?: boolean } = {}) => {
-  const {
-    doGeneralOverrides = false,
-  } = opts;
+export const getDiForUnitTesting = (
+  opts: { doGeneralOverrides?: boolean } = {},
+) => {
+  const { doGeneralOverrides = false } = opts;
 
   const di = createContainer("renderer");
 
-  registerMobX(di);
+  di.preventSideEffects();
 
   setLegacyGlobalDiForExtensionApi(di, Environments.renderer);
 
-  const filePaths = getInjectableFilePaths();
+  const injectables: Injectable<any, any, any>[] = (
+      global as any
+  ).rendererInjectablePaths.map(
+    (filePath: string) => require(filePath).default,
+  );
 
-  const injectables = filePaths.map(filePath => require(filePath).default);
+  runInAction(() => {
+    registerMobX(di);
 
-  chunk(100)(injectables).forEach(chunkInjectables => {
-    di.register(...chunkInjectables);
+    chunk(100)(injectables).forEach((chunkInjectables) => {
+      di.register(...chunkInjectables);
+    });
   });
 
-  di.preventSideEffects();
-
   if (doGeneralOverrides) {
-    const globalOverrideFilePaths = getGlobalOverridePaths();
-
-    const globalOverrides = globalOverrideFilePaths.map(
-      (filePath) => require(filePath).default,
+    const globalOverrides: GlobalOverride[] = (global as any).rendererGlobalOverridePaths.map(
+      (filePath: string) => require(filePath).default,
     );
 
     globalOverrides.forEach(globalOverride => {
@@ -118,8 +114,6 @@ export const getDiForUnitTesting = (opts: { doGeneralOverrides?: boolean } = {})
     di.override(getAbsolutePathInjectable, () => getAbsolutePathFake);
     di.override(joinPathsInjectable, () => joinPathsFake);
 
-    di.override(appVersionInjectable, () => "1.0.0");
-
     di.override(historyInjectable, () => createMemoryHistory());
     di.override(legacyOnChannelListenInjectable, () => () => noop);
 
@@ -170,11 +164,6 @@ export const getDiForUnitTesting = (opts: { doGeneralOverrides?: boolean } = {})
     di.override(maximizeWindowInjectable, () => () => {});
     di.override(toggleMaximizeWindowInjectable, () => () => {});
 
-    di.override(ipcRendererInjectable, () => ({
-      invoke: () => {},
-      on: () => {},
-    }) as unknown as IpcRenderer);
-
     overrideFunctionalInjectables(di, [
       broadcastMessageInjectable,
       getFilePathsInjectable,
@@ -191,26 +180,19 @@ export const getDiForUnitTesting = (opts: { doGeneralOverrides?: boolean } = {})
 
     di.override(fileSystemProvisionerStoreInjectable, () => ({}) as FileSystemProvisionerStore);
 
-    // eslint-disable-next-line unused-imports/no-unused-vars-ts
-    di.override(clusterStoreInjectable, () => ({ getById: (id): Cluster => ({}) as Cluster }) as ClusterStore);
-
     di.override(setupSystemCaInjectable, () => ({ run: () => {} }));
     di.override(setupOnApiErrorListenersInjectable, () => ({ run: () => {} }));
-    di.override(provideInitialValuesForSyncBoxesInjectable, () => ({ run: () => {} }));
 
     di.override(defaultShellInjectable, () => "some-default-shell");
 
-    di.override(
-      userStoreInjectable,
-      () =>
-        ({
-          isTableColumnHidden: () => false,
-          extensionRegistryUrl: { customUrl: "some-custom-url" },
-          syncKubeconfigEntries: observable.map(),
-          terminalConfig: { fontSize: 42 },
-          editorConfiguration: { minimap: {}, tabSize: 42, fontSize: 42 },
-        } as unknown as UserStore),
-    );
+    di.override(userStoreInjectable, () => ({
+      isTableColumnHidden: () => false,
+      extensionRegistryUrl: { customUrl: "some-custom-url" },
+      syncKubeconfigEntries: observable.map(),
+      terminalConfig: { fontSize: 42 },
+      editorConfiguration: { minimap: {}, tabSize: 42, fontSize: 42 },
+      load: () => {},
+    } as PartialDeep<UserStore> as UserStore));
 
     di.override(apiManagerInjectable, () => new ApiManager());
 
@@ -232,20 +214,6 @@ export const getDiForUnitTesting = (opts: { doGeneralOverrides?: boolean } = {})
   return di;
 };
 
-const getInjectableFilePaths = memoize(() => [
-  ...glob.sync("./**/*.injectable.{ts,tsx}", { cwd: __dirname }),
-  ...glob.sync("../common/**/*.injectable.{ts,tsx}", { cwd: __dirname }),
-  ...glob.sync("../extensions/**/*.injectable.{ts,tsx}", { cwd: __dirname }),
-]);
-
-const getGlobalOverridePaths = memoize(() =>
-  glob.sync(
-    "../{common,extensions,renderer}/**/*.global-override-for-injectable.{ts,tsx}",
-
-    { cwd: __dirname },
-  ),
-);
-
 const overrideFunctionalInjectables = (di: DiContainer, injectables: Injectable<any, any, any>[]) => {
   injectables.forEach(injectable => {
     di.override(injectable, () => () => {
