@@ -3,6 +3,7 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import type { DiContainer } from "@ogre-tools/injectable";
+import { runInAction } from "mobx";
 import type { CreateStorage } from "./create-storage";
 import createStorageInjectable from "./create-storage.injectable";
 
@@ -19,8 +20,10 @@ export const controlWhenStoragesAreReady = (di: DiContainer) => {
             return storage;
           };
 
-  // TODO: Remove when typing is added to the library
-  (di as any).decorateFunction(createStorageInjectable, decorated);
+  runInAction(() => {
+    // TODO: Remove when typing is added to the library
+    (di as any).decorateFunction(createStorageInjectable, decorated);
+  });
 
   return async () => {
     await Promise.all(storagesAreReady);
